package com.gxlu.ps.netcruise.md;

import com.gxlu.ps.netcruise.md.buffer.AlarmPool;
import com.gxlu.ps.netcruise.md.buffer.CmdPool;
import com.gxlu.ps.netcruise.md.cmdchannel.CmdListener;
import com.gxlu.ps.netcruise.md.nmsctrl.NMSCommunicatorMgr;
import com.gxlu.ps.netcruise.md.sender.AlarmSender;
import com.gxlu.ps.netcruise.md.sender.TestSender;
import java.io.File;
import org.apache.log4j.Logger;

/* loaded from: com_gxlu_ps_netcruise_md.jar:com/gxlu/ps/netcruise/md/MDCtrl.class */
public class MDCtrl {
    private static MDCtrl instance = null;
    private NMSCommunicatorMgr nmsMgr = null;
    private AlarmPool alarmPool = null;
    private AlarmSender alarmSender = null;
    private CmdPool cmdPool = null;
    private Configer configer = null;
    private CmdListener cmdListener = null;
    private ShutdownDaemon guard = null;
    private Logger logger = null;
    private TestSender testSender = null;

    private MDCtrl() {
    }

    public static MDCtrl getInstance() {
        if (instance == null) {
            instance = new MDCtrl();
        }
        return instance;
    }

    protected boolean checkConf(Configer conf) {
        if (conf.getAlarmFilePath() == null) {
            this.logger.error("**Alarm file path error!");
            return false;
        }
        if (conf.getCmdFilePath() == null) {
            this.logger.error("**Command file path error!");
            return false;
        }
        if (conf.getErrFilePath() == null) {
            this.logger.error("**Error file path error!");
            return false;
        }
        if (conf.getAlarmLogPath() == null) {
            this.logger.error("**Alarm Log path error!");
            return false;
        }
        File f = new File(conf.getErrFilePath());
        if (!f.exists()) {
            this.logger.error("**Error file doesn't exists!");
            return false;
        }
        if (conf.getControlPort() <= 0) {
            this.logger.error("**Telnet port value error!");
            return false;
        }
        if (conf.getTimeOut() <= 0) {
            this.logger.error("**Time out value error!");
            return false;
        }
        if (conf.getTelnetCmdWaitTime() <= 0) {
            this.logger.error("**Telnet command wait time value error!");
            return false;
        }
        if (conf.getListenNMSPort() <= 0) {
            this.logger.error("**Listen NMS port value error!");
            return false;
        }
        if (conf.getTimeCommandInterval() <= 0) {
            this.logger.error("**Time command interval value error!");
            return false;
        }
        if (conf.getMaxRetryInterval() <= 0) {
            this.logger.error("**Retry interval upper limit value error!");
            return false;
        }
        if (conf.getMaxNMSCount() <= 0) {
            this.logger.error("**NMS count upper limit value error!");
            return false;
        }
        if (conf.getBufferSize() <= 0) {
            this.logger.error("**Buffer size value error!");
            return false;
        }
        if (conf.getSendCacheSize() <= 0) {
            this.logger.error("**Send cache size value error!");
            return false;
        }
        if (conf.getNetcoolAddr() == null) {
            this.logger.error("**Netcool address value error!");
            return false;
        }
        if (conf.getNetcoolPort() <= 0) {
            this.logger.error("**Netcool port value error!");
            return false;
        }
        String[] nmsList = conf.getNMSList();
        if (nmsList == null) {
            this.logger.error("**Need NMS!");
            return false;
        }
        if (nmsList.length <= 0) {
            this.logger.error("**Need NMS!");
            return false;
        }
        for (int i = 0; i < nmsList.length; i++) {
            if (conf.getNMSInfo(nmsList[i], "specialty") == null) {
                this.logger.error(String.valueOf(String.valueOf(new StringBuffer("**").append(nmsList[i]).append("'s specialty error!"))));
                return false;
            }
            if (conf.getNMSInfo(nmsList[i], "address") == null) {
                this.logger.error(String.valueOf(String.valueOf(new StringBuffer("**").append(nmsList[i]).append("'s address error!"))));
                return false;
            }
            if (conf.getNMSInfo(nmsList[i], "remote_port") == null) {
                this.logger.error(String.valueOf(String.valueOf(new StringBuffer("**").append(nmsList[i]).append("'s remote port error!"))));
                return false;
            }
            if (conf.getNMSInfo(nmsList[i], "local_port") == null) {
                this.logger.error(String.valueOf(String.valueOf(new StringBuffer("**").append(nmsList[i]).append("'s local port error!"))));
                return false;
            }
        }
        return true;
    }

    public void startUp(String[] args) {
        System.out.println("************************************************************");
        System.out.println("* Program Name: MD(general)                                *");
        System.out.println("* Version: 1.0.0                                           *");
        System.out.println("* Copyright (c) GXLU PS.  All rights reserved.             *");
        System.out.println("* Visit http://www.gxlu.com.cn                             *");
        System.out.println("************************************************************");
        System.out.println("");
        this.logger = GlobalInstance.getInstance().getLogger();
        this.logger.info("Program name: MD(general)");
        this.logger.info("MD.version=1.0.0");
        this.logger.info("MD.vendor=GXLU.PS");
        this.logger.info("Description: Copyright (c) GXLU PS.  All rights reserved.");
        this.logger.info("MD starting up.");
        this.guard = new ShutdownDaemon();
        Runtime.getRuntime().addShutdownHook(this.guard);
        if (args.length > 0) {
            GlobalInstance.getInstance().setCfgFilePath(args[0]);
        }
        initCore();
        this.logger.info("MD has startuped.");
        beginToServe();
    }

    public void beginToServe() {
        this.logger.info("Starting the command listener......");
        this.cmdListener = GlobalInstance.getInstance().getCmdListener();
        this.logger.info("Command listener started.");
        this.cmdListener.listenAndServe();
    }

    public void initCore() {
        GlobalInstance global = GlobalInstance.getInstance();
        this.configer = global.getConfiger();
        if (this.configer == null) {
            this.logger.error("**Can't find or open configure file, please make sure that it's exist.");
            System.exit(0);
        }
        if (!checkConf(this.configer)) {
            this.logger.error("**There are some problems with configure file, please check it.");
            System.exit(0);
        }
        this.logger.info("Initializing the core......");
        this.alarmPool = global.getAlarmPool();
        this.cmdPool = global.getCmdPool();
        this.logger.error("Initializing core done.");
        String mode = this.configer.checkRunMode();
        if (mode.equals("TEST")) {
            this.logger.error("Starting the test sender......");
            this.testSender = global.getTestSender();
            this.testSender.setName("testSender");
            this.testSender.start();
            this.logger.error("Test sender started.");
        }
        this.logger.info("Starting the alarm sender......");
        this.alarmSender = global.getAlarmSender();
        this.alarmSender.setName("alarmSender");
        this.alarmSender.start();
        this.logger.info("Alarm sender started.");
        this.logger.info("Starting the NMS manager......");
        this.nmsMgr = global.getNMSCommunicatorMgr();
        this.nmsMgr.loadAllNMS();
        this.nmsMgr.startAllNMSComm();
        this.logger.info("NMS manager started.");
    }

    public static void main(String[] args) {
        MDCtrl mdCtrl = getInstance();
        mdCtrl.startUp(args);
    }
}
